@@ -311,14 +311,20 @@ def process_excel_file(
         "CLOSED",
     ]
 
-    jira_query_result = jira_client.get_stories_status(
-        [s["storyId"].strip() for s in stories]
-    )
+    stories_has_story_id = []
+    for story in stories:
+        if story["storyId"] is not None:
+            stories_has_story_id.append(story["storyId"].strip())
+
+    jira_query_result = jira_client.get_stories_status(stories_has_story_id)
 
     stories_need_sort = []
     stories_no_need_sort = []
 
     for story in stories:
+        if story["storyId"] is None:
+            stories_need_sort.append(story)
+            continue
         story_id: str = story["storyId"].lower().strip()
         if story_id in jira_query_result:
             story["status"] = jira_query_result[story_id]
